// @(#)root/mathcore:$Id$
// Authors: W. Brown, M. Fischler, L. Moneta    2005

#ifndef ROOT_Math_GenVector_Cartesian2Dfwd
#define ROOT_Math_GenVector_Cartesian2Dfwd  1


namespace ROOT {

  namespace Math {

     template <class T>
     class Cartesian2D;

  } // end namespace Math

} // end namespace ROOT


#endif /* ROOT_Math_GenVector_Cartesian2Dfwd  */
